@@ -19,6 +19,7 @@
 # along with PyEPR.  If not, see <http://www.gnu.org/licenses/>.
 
 import os
+import re
 import sys
 import unittest
 import functools
@@ -28,6 +29,23 @@ import numpy as np
 sys.path.insert(0, os.pardir)
 import epr
 
+
+EPR_TO_NUMPY_TYPE = {
+    #epr.E_TID_UNKNOWN:  np.NPY_NOTYPE,
+    epr.E_TID_UCHAR:    np.ubyte,
+    epr.E_TID_CHAR:     np.byte,
+    epr.E_TID_USHORT:   np.ushort,
+    epr.E_TID_SHORT:    np.short,
+    epr.E_TID_UINT:     np.uint,
+    epr.E_TID_INT:      np.int,
+    epr.E_TID_FLOAT:    np.float32,
+    epr.E_TID_DOUBLE:   np.double,
+    epr.E_TID_STRING:   np.str,
+    #epr.E_TID_SPARE   = e_tid_spare,
+    #epr.E_TID_TIME    = e_tid_time,
+}
+
+
 TEST_PRODUCT = 'ASA_IMP_1PNUPA20060202_062233_000000152044_00435_20529_3110.N1'
 
 def quiet(func):
@@ -140,7 +158,7 @@ class TestProduct(unittest.TestCase):
     def test_datasets(self):
         datasets = [self.product.get_dataset_at(idx)
                         for idx in range(self.product.get_num_datasets())]
-        dataset_names = [ds.get_dataset_name() for ds in datasets]
+        dataset_names = [ds.get_name() for ds in datasets]
         self.assertEqual(dataset_names, self.DATASET_NAMES)
 
     def test_get_dsd_at(self):
@@ -149,27 +167,27 @@ class TestProduct(unittest.TestCase):
     def test_get_mph(self):
         record = self.product.get_mph()
         self.assertTrue(isinstance(record, epr.Record))
-        self.assertEqual(record.get_field('PRODUCT').get_field_elem(),
+        self.assertEqual(record.get_field('PRODUCT').get_elem(),
                          self.PRODUCT_FILE)
 
     def test_get_sph(self):
         record = self.product.get_sph()
         self.assertTrue(isinstance(record, epr.Record))
-        self.assertEqual(record.get_field('SPH_DESCRIPTOR').get_field_elem(),
+        self.assertEqual(record.get_field('SPH_DESCRIPTOR').get_elem(),
                          "Image Mode Precision Image")
 
     def test_get_band_id(self):
-        self.assertTrue(isinstance(self.product.get_band_id('proc_data'),
+        self.assertTrue(isinstance(self.product.get_band('proc_data'),
                                    epr.Band))
 
     def test_get_band_id_invalid_name(self):
-        self.assertRaises(ValueError, self.product.get_band_id, '')
+        self.assertRaises(ValueError, self.product.get_band, '')
 
     def test_get_band_id_at(self):
-        self.assertTrue(isinstance(self.product.get_band_id_at(0), epr.Band))
+        self.assertTrue(isinstance(self.product.get_band_at(0), epr.Band))
 
     def test_get_band_id_at_invalid_index(self):
-        self.assertRaises(ValueError, self.product.get_band_id_at,
+        self.assertRaises(ValueError, self.product.get_band_at,
                             self.product.get_num_bands())
 
     #def test_read_bitmask_raster(self):
@@ -188,6 +206,36 @@ class TestProduct(unittest.TestCase):
     #    self.assertEqual(raster.get_raster_height(), height)
 
 
+class TestProductHighLevelAPI(unittest.TestCase):
+    PRODUCT_FILE = TEST_PRODUCT
+    DATASET_NAMES = [
+        'MDS1_SQ_ADS',
+        'MAIN_PROCESSING_PARAMS_ADS',
+        'DOP_CENTROID_COEFFS_ADS',
+        'SR_GR_ADS',
+        'CHIRP_PARAMS_ADS',
+        'GEOLOCATION_GRID_ADS',
+        'MDS1'
+    ]
+
+    BAND_NAMES = [
+        'slant_range_time',
+        'incident_angle',
+        'latitude',
+        'longitude',
+        'proc_data',
+    ]
+
+    def setUp(self):
+        self.product = epr.Product(self.PRODUCT_FILE)
+
+    def test_get_dataset_names(self):
+        self.assertEqual(self.product.get_dataset_names(), self.DATASET_NAMES)
+
+    def test_get_band_names(self):
+        self.assertEqual(self.product.get_band_names(), self.BAND_NAMES)
+
+
 class TestDataset(unittest.TestCase):
     PRODUCT_FILE = TEST_PRODUCT
     DATASET_NAME = 'MDS1'
@@ -196,14 +244,14 @@ class TestDataset(unittest.TestCase):
         self.product = epr.Product(self.PRODUCT_FILE)
         self.dataset = self.product.get_dataset(self.DATASET_NAME)
 
-    def test_product_id_property(self):
-        self.assertTrue(equal_products(self.dataset.product_id, self.product))
+    def test_product_property(self):
+        self.assertTrue(equal_products(self.dataset.product, self.product))
 
     def test_description_property(self):
         self.assertEqual(self.dataset.description, 'Measurement Data Set 1')
 
-    def test_get_dataset_name(self):
-        self.assertEqual(self.dataset.get_dataset_name(), self.DATASET_NAME)
+    def test_get_name(self):
+        self.assertEqual(self.dataset.get_name(), self.DATASET_NAME)
 
     def test_get_dsd_name(self):
         self.assertEqual(self.dataset.get_dsd_name(), self.DATASET_NAME)
@@ -257,10 +305,10 @@ class TestBand(unittest.TestCase):
 
     def setUp(self):
         self.product = epr.Product(self.PRODUCT_FILE)
-        self.band = self.product.get_band_id('proc_data')
+        self.band = self.product.get_band('proc_data')
 
-    def test_product_id_property(self):
-        self.assertTrue(equal_products(self.band.product_id, self.product))
+    def test_product_property(self):
+        self.assertTrue(equal_products(self.band.product, self.product))
 
     # @TODO: check
     #def test_dataset_ref_property(self):
@@ -298,18 +346,18 @@ class TestBand(unittest.TestCase):
         self.assertTrue(isinstance(self.band.lines_mirrored, bool))
         self.assertEqual(self.band.lines_mirrored, True)
 
-    def test_get_band_name(self):
+    def test_get_name(self):
         for index in range(len(self.BAND_NAMES)):
-            b = self.product.get_band_id_at(index)
-            self.assertEqual(b.get_band_name(), self.BAND_NAMES[index])
+            b = self.product.get_band_at(index)
+            self.assertEqual(b.get_name(), self.BAND_NAMES[index])
 
     def test_create_compatible_raster(self):
         width = self.product.get_scene_width()
         height = self.product.get_scene_height()
         raster = self.band.create_compatible_raster(width, height)
         self.assertTrue(isinstance(raster, epr.Raster))
-        self.assertEqual(raster.get_raster_width(), width)
-        self.assertEqual(raster.get_raster_height(), height)
+        self.assertEqual(raster.get_width(), width)
+        self.assertEqual(raster.get_height(), height)
         # @NOTE: data type on disk is epr.E_TID_USHORT
         self.assertEqual(raster.data_type, epr.E_TID_FLOAT)
 
@@ -339,8 +387,8 @@ class TestBand(unittest.TestCase):
         raster = self.band.create_compatible_raster(src_width, src_height,
                                                     xstep, ystep)
         self.assertTrue(isinstance(raster, epr.Raster))
-        self.assertEqual(raster.get_raster_width(), width)
-        self.assertEqual(raster.get_raster_height(), height)
+        self.assertEqual(raster.get_width(), width)
+        self.assertEqual(raster.get_height(), height)
         # @NOTE: data type on disk is epr.E_TID_USHORT
         self.assertEqual(raster.data_type, epr.E_TID_FLOAT)
 
@@ -369,53 +417,50 @@ class TestBand(unittest.TestCase):
         #                  self.band.create_compatible_raster,
         #                  width, height, width + 10, height + 10)
 
-    def test_read_band_raster(self):
+    def test_read_raster(self):
         width = 400
         height = 300
         raster = self.band.create_compatible_raster(width, height)
 
-        self.band.read_band_raster(self.XOFFSET, self.YOFFSET, raster)
+        self.band.read_raster(self.XOFFSET, self.YOFFSET, raster)
 
         self.assertTrue(isinstance(raster, epr.Raster))
-        self.assertEqual(raster.get_raster_width(), width)
-        self.assertEqual(raster.get_raster_height(), height)
+        self.assertEqual(raster.get_width(), width)
+        self.assertEqual(raster.get_height(), height)
         # @NOTE: data type on disk is epr.E_TID_USHORT
         self.assertEqual(raster.data_type, epr.E_TID_FLOAT)
 
-    def test_read_band_raster_default_offset(self):
+    def test_read_raster_default_offset(self):
         height, width = self.TEST_DATA.shape
 
         raster1 = self.band.create_compatible_raster(width, height)
         raster2 = self.band.create_compatible_raster(width, height)
 
-        self.band.read_band_raster(0, 0, raster1)
-        self.band.read_band_raster(raster=raster2)
+        self.band.read_raster(0, 0, raster1)
+        self.band.read_raster(raster=raster2)
 
         self.assertEqual(raster1.get_pixel(0, 0), raster2.get_pixel(0, 0))
         self.assertEqual(raster1.get_pixel(width - 1, height -1),
                           raster2.get_pixel(width - 1, height -1))
 
-    def test_read_band_raster_with_invalid_raster(self):
-        self.assertRaises(TypeError, self.band.read_band_raster, 0, 0, 0)
+    def test_read_raster_with_invalid_raster(self):
+        self.assertRaises(TypeError, self.band.read_raster, 0, 0, 0)
 
-    def test_read_band_raster_with_invalid_offset(self):
+    def test_read_raster_with_invalid_offset(self):
         width = 400
         height = 300
         raster = self.band.create_compatible_raster(width, height)
 
         # @TODO: check
-        self.assertRaises(ValueError, self.band.read_band_raster,
-                          -1, 0, raster)
-        self.assertRaises(ValueError, self.band.read_band_raster,
-                          0, -1, raster)
-        self.assertRaises(ValueError, self.band.read_band_raster,
-                          -1, -1, raster)
+        self.assertRaises(ValueError, self.band.read_raster, -1, 0, raster)
+        self.assertRaises(ValueError, self.band.read_raster, 0, -1, raster)
+        self.assertRaises(ValueError, self.band.read_raster, -1, -1, raster)
         # @TODO: check
-        #self.assertRaises(ValueError, self.band.read_band_raster,
+        #self.assertRaises(ValueError, self.band.read_raster,
         #                  width + 10, 0, raster)
-        #self.assertRaises(ValueError, self.band.read_band_raster,
+        #self.assertRaises(ValueError, self.band.read_raster,
         #                  0, height + 10, raster)
-        #self.assertRaises(ValueError, self.band.read_band_raster,
+        #self.assertRaises(ValueError, self.band.read_raster,
         #                  width + 10, height + 10, raster)
 
     def test_read_as_array(self):
@@ -461,8 +506,8 @@ class TestCreateRaster(unittest.TestCase):
                                    self.RASTER_HEIGHT)
         self.assertTrue(isinstance(raster, epr.Raster))
         self.assertEqual(raster.data_type, self.RASTER_DATA_TYPE)
-        self.assertEqual(raster.get_raster_width(), self.RASTER_WIDTH)
-        self.assertEqual(raster.get_raster_height(), self.RASTER_HEIGHT)
+        self.assertEqual(raster.get_width(), self.RASTER_WIDTH)
+        self.assertEqual(raster.get_height(), self.RASTER_HEIGHT)
 
     def test_create_raster_with_step(self):
         src_width = 3 * self.RASTER_WIDTH
@@ -471,8 +516,8 @@ class TestCreateRaster(unittest.TestCase):
                                    src_width, src_height, 3, 2)
         self.assertTrue(isinstance(raster, epr.Raster))
         self.assertEqual(raster.data_type, self.RASTER_DATA_TYPE)
-        self.assertEqual(raster.get_raster_width(), self.RASTER_WIDTH)
-        self.assertEqual(raster.get_raster_height(), self.RASTER_HEIGHT)
+        self.assertEqual(raster.get_width(), self.RASTER_WIDTH)
+        self.assertEqual(raster.get_height(), self.RASTER_HEIGHT)
 
     def test_create_raster_with_invalid_step(self):
         src_width = 3 * self.RASTER_WIDTH
@@ -489,8 +534,8 @@ class TestCreateRaster(unittest.TestCase):
                                            self.RASTER_HEIGHT)
         self.assertTrue(isinstance(raster, epr.Raster))
         self.assertEqual(raster.data_type, epr.E_TID_UCHAR)
-        self.assertEqual(raster.get_raster_width(), self.RASTER_WIDTH)
-        self.assertEqual(raster.get_raster_height(), self.RASTER_HEIGHT)
+        self.assertEqual(raster.get_width(), self.RASTER_WIDTH)
+        self.assertEqual(raster.get_height(), self.RASTER_HEIGHT)
 
     def test_create_bitmask_raster_with_step(self):
         src_width = 3 * self.RASTER_WIDTH
@@ -498,8 +543,8 @@ class TestCreateRaster(unittest.TestCase):
         raster = epr.create_bitmask_raster(src_width, src_height, 3, 2)
         self.assertTrue(isinstance(raster, epr.Raster))
         self.assertEqual(raster.data_type, epr.E_TID_UCHAR)
-        self.assertEqual(raster.get_raster_width(), self.RASTER_WIDTH)
-        self.assertEqual(raster.get_raster_height(), self.RASTER_HEIGHT)
+        self.assertEqual(raster.get_width(), self.RASTER_WIDTH)
+        self.assertEqual(raster.get_height(), self.RASTER_HEIGHT)
 
     def test_create_bitmask_raster_with_invalid_step(self):
         src_width = 3 * self.RASTER_WIDTH
@@ -523,15 +568,14 @@ class TestRaster(unittest.TestCase):
         self.raster = epr.create_raster(self.RASTER_DATA_TYPE,
                                         self.RASTER_WIDTH, self.RASTER_HEIGHT)
 
-    def test_get_raster_width(self):
-        self.assertEqual(self.raster.get_raster_width(), self.RASTER_WIDTH)
+    def test_get_width(self):
+        self.assertEqual(self.raster.get_width(), self.RASTER_WIDTH)
 
-    def test_get_raster_height(self):
-        self.assertEqual(self.raster.get_raster_height(), self.RASTER_HEIGHT)
+    def test_get_height(self):
+        self.assertEqual(self.raster.get_height(), self.RASTER_HEIGHT)
 
-    def test_get_raster_elem_size(self):
-        self.assertEqual(self.raster.get_raster_elem_size(),
-                         self.RASTER_ELEM_SIZE)
+    def test_get_elem_size(self):
+        self.assertEqual(self.raster.get_elem_size(), self.RASTER_ELEM_SIZE)
 
     def test_get_pixel(self):
         self.assertEqual(self.raster.get_pixel(0, 0), self.TEST_DATA[0, 0])
@@ -574,22 +618,21 @@ class TestRaster(unittest.TestCase):
         self.assertTrue(isinstance(self.raster.source_step_y, (int, long)))
 
     def test_data_property(self):
-        height = self.raster.get_raster_height()
-        width = self.raster.get_raster_width()
+        height = self.raster.get_height()
+        width = self.raster.get_width()
 
         data = self.raster.data
 
         self.assertTrue(isinstance(data, np.ndarray))
         self.assertEqual(data.ndim, 2)
         self.assertEqual(data.shape, (height, width))
-        self.assertEqual(data.dtype,
-                         epr.epr_to_numpy_type[self.raster.data_type])
+        self.assertEqual(data.dtype, EPR_TO_NUMPY_TYPE[self.raster.data_type])
         self.assertTrue(np.all(data[:10, :10] == self.TEST_DATA))
 
     def test_data_property_two_times(self):
         data1 = self.raster.data
         data2 = self.raster.data
-        self.assertFalse(data1 is data2)    # @TODO: check
+        self.assertTrue(data1 is data2)
         self.assertTrue(np.all(data1 == data2))
 
     def test_data_property_shared_data_semantic(self):
@@ -633,18 +676,18 @@ class TestRasterRead(TestRaster):
 
     def setUp(self):
         self.product = epr.Product(self.PRODUCT_FILE)
-        self.band = self.product.get_band_id(self.BAND_NAME)
+        self.band = self.product.get_band(self.BAND_NAME)
         self.raster = self.band.create_compatible_raster(self.RASTER_WIDTH,
                                                          self.RASTER_HEIGHT)
 
-        self.band.read_band_raster(self.RASTER_XOFFSET, self.RASTER_YOFFSET,
-                                   self.raster)
+        self.band.read_raster(self.RASTER_XOFFSET, self.RASTER_YOFFSET,
+                              self.raster)
 
     def test_data_property_shared_semantics_readload(self):
         data1 = self.raster.data
         data1[0, 0] *= 2
-        self.band.read_band_raster(self.RASTER_XOFFSET, self.RASTER_YOFFSET,
-                                   self.raster)
+        self.band.read_raster(self.RASTER_XOFFSET, self.RASTER_YOFFSET,
+                              self.raster)
         data2 = self.raster.data
         self.assertEqual(data1[0, 0], data2[0, 0])
         self.assertTrue(np.all(data1 == data2))
@@ -678,15 +721,15 @@ class TestRecord(unittest.TestCase):
     #        self.assertRaises(ValueError, self.record.dump_element, 0, 150)
 
     @quiet
-    def test_print_record(self):
-        self.record.print_record()
+    def test_print_(self):
+        self.record.print_()
 
     @quiet
-    def test_print_record_ostream(self):
-        self.record.print_record(sys.stderr)
+    def test_print_ostream(self):
+        self.record.print_(sys.stderr)
 
-    def test_print_record_invalid_ostream(self):
-        self.assertRaises(TypeError, self.record.print_record, 'invalid')
+    def test_print_invalid_ostream(self):
+        self.assertRaises(TypeError, self.record.print_, 'invalid')
 
     @quiet
     def test_print_element(self):
@@ -721,6 +764,60 @@ class TestRecord(unittest.TestCase):
         self.assertRaises(ValueError, self.record.get_field_at, index)
 
 
+class TestRecordHighLevelAPI(unittest.TestCase):
+    PRODUCT_FILE = TEST_PRODUCT
+    DATASET_NAME = 'MAIN_PROCESSING_PARAMS_ADS'
+    FIELD_NAMES = [
+        'first_zero_doppler_time',
+        'attach_flag',
+        'last_zero_doppler_time',
+        'work_order_id',
+        'time_diff',
+        'swath_id',
+        'range_spacing',
+        'azimuth_spacing',
+        'line_time_interval',
+        'num_output_lines',
+        'num_samples_per_line',
+        'data_type',
+    ]
+
+    def setUp(self):
+        product = epr.Product(self.PRODUCT_FILE)
+        dataset = product.get_dataset(self.DATASET_NAME)
+        self.record = dataset.read_record(0)
+
+    def test_get_field_names_number(self):
+        self.assertEqual(len(self.record.get_field_names()),
+                         self.record.get_num_fields())
+
+    def test_get_field_names(self):
+        self.assertEqual(self.record.get_field_names()[:len(self.FIELD_NAMES)],
+                         self.FIELD_NAMES)
+
+
+class TestMphRecordHighLevelAPI(TestRecordHighLevelAPI):
+    PRODUCT_FILE = TEST_PRODUCT
+    DATASET_NAME = 'MPH'
+    FIELD_NAMES = [
+        'PRODUCT',
+        'PROC_STAGE',
+        'REF_DOC',
+        'ACQUISITION_STATION',
+        'PROC_CENTER',
+        'PROC_TIME',
+        'SOFTWARE_VER',
+        'SENSING_START',
+        'SENSING_STOP',
+        'PHASE',
+        'CYCLE',
+        'REL_ORBIT',
+    ]
+
+    def setUp(self):
+        product = epr.Product(self.PRODUCT_FILE)
+        self.record = product.get_mph()
+
 class TestField(unittest.TestCase):
     PRODUCT_FILE = TEST_PRODUCT
     DATASET_NAME = 'MAIN_PROCESSING_PARAMS_ADS'
@@ -741,48 +838,47 @@ class TestField(unittest.TestCase):
 
     @quiet
     def test_print_field(self):
-        self.field.print_field()
+        self.field.print_()
 
     @quiet
-    def test_print_fied_ostream(self):
-        self.field.print_field(sys.stderr)
+    def test_print_field_ostream(self):
+        self.field.print_(sys.stderr)
 
     def test_print_fied_invalid_ostream(self):
-        self.assertRaises(TypeError, self.field.print_field, 'invalid')
+        self.assertRaises(TypeError, self.field.print_, 'invalid')
 
     #if ALLOW_DUMP:
     #    def test_dump_field(self):
     #        self.field.dump_field()
 
-    def test_get_field_unit(self):
-        self.assertEqual(self.field.get_field_unit(), self.FIELD_UNIT)
+    def test_get_unit(self):
+        self.assertEqual(self.field.get_unit(), self.FIELD_UNIT)
 
-    def test_get_field_description(self):
-        self.assertEqual(self.field.get_field_description(),
-                         self.FIELD_DESCRIPTION)
+    def test_get_description(self):
+        self.assertEqual(self.field.get_description(), self.FIELD_DESCRIPTION)
 
-    def test_get_field_num_elems(self):
-        self.assertEqual(self.field.get_field_num_elems(), self.FIELD_NUM_ELEMS)
+    def test_get_num_elems(self):
+        self.assertEqual(self.field.get_num_elems(), self.FIELD_NUM_ELEMS)
 
-    def test_get_field_name(self):
-        self.assertEqual(self.field.get_field_name(), self.FIELD_NAME)
+    def test_get_name(self):
+        self.assertEqual(self.field.get_name(), self.FIELD_NAME)
 
-    def test_get_field_type(self):
-        self.assertEqual(self.field.get_field_type(), self.FIELD_TYPE)
+    def test_get_type(self):
+        self.assertEqual(self.field.get_type(), self.FIELD_TYPE)
 
-    def test_get_field_elem(self):
-        self.assertEqual(self.field.get_field_elem(), self.FIELD_VALUES[0])
+    def test_get_elem(self):
+        self.assertEqual(self.field.get_elem(), self.FIELD_VALUES[0])
 
-    def test_get_field_elem_index(self):
-        self.assertEqual(self.field.get_field_elem(0), self.FIELD_VALUES[0])
+    def test_get_elem_index(self):
+        self.assertEqual(self.field.get_elem(0), self.FIELD_VALUES[0])
 
-    def test_get_field_elem_invalid_index(self):
-        self.assertRaises(ValueError, self.field.get_field_elem, 100)
+    def test_get_elem_invalid_index(self):
+        self.assertRaises(ValueError, self.field.get_elem, 100)
 
-    def test_get_field_elems(self):
-        vect = self.field.get_field_elems()
+    def test_get_elems(self):
+        vect = self.field.get_elems()
         self.assertTrue(isinstance(vect, np.ndarray))
-        self.assertEqual(vect.shape, (self.field.get_field_num_elems(),))
+        self.assertEqual(vect.shape, (self.field.get_num_elems(),))
         self.assertEqual(vect.dtype, np.float32)
         self.assertTrue(np.allclose(vect, self.FIELD_VALUES))
 
@@ -916,23 +1012,59 @@ class TestSampleModelFunctions(unittest.TestCase):
 
 
 class TestDirectInstantiation(unittest.TestCase):
+    MSG_PATTERN = '"%s" class cannot be instantiated from Python'
+
+    if sys.version_info[:2] > (3,2):
+        # @COMPATIBILITY: python >= 3.2
+        pass
+    elif sys.version_info[:2] in ((2.7), (3,1)):
+        # @COMPATIBILITY: unittest2, python2.7, python3.1
+        assertRaiserRegex = assertRaiserRegexp
+    else:
+        # @COMPATIBILITY: python < 2.7
+        def assertRaisesRegex(self, expected_exception, expected_regexp,
+                              callable_obj=None, *args, **kwargs):
+            try:
+                callable_obj(*args, **kwargs)
+            except expected_exception, exc_value:
+                if isinstance(expected_regexp, basestring):
+                    expected_regexp = re.compile(expected_regexp)
+                if not expected_regexp.search(str(exc_value)):
+                    raise self.failureException('"%s" does not match "%s"' %
+                             (expected_regexp.pattern, str(exc_value)))
+            else:
+                if hasattr(expected_exception, '__name__'):
+                    excName = expected_exception.__name__
+                else:
+                    excName = str(expected_exception)
+                raise self.failureException, "%s not raised" % excName
+
     def test_direct_dsd_instantiation(self):
-        self.assertRaises(TypeError, epr.DSD)
+        pattern = self.MSG_PATTERN % epr.DSD.__name__
+        self.assertRaisesRegex(TypeError, pattern, epr.DSD)
 
     def test_direct_field_instantiation(self):
-        self.assertRaises(TypeError, epr.Field)
+        pattern = self.MSG_PATTERN % epr.Field.__name__
+        self.assertRaisesRegex(TypeError, pattern, epr.Field)
 
     def test_direct_record_instantiation(self):
-        self.assertRaises(TypeError, epr.Record)
+        pattern = self.MSG_PATTERN % epr.Record.__name__
+        self.assertRaisesRegex(TypeError, pattern, epr.Record)
 
     def test_direct_raster_instantiation(self):
-        self.assertRaises(TypeError, epr.Raster)
+        pattern = self.MSG_PATTERN % epr.Raster.__name__
+        self.assertRaisesRegex(TypeError, pattern, epr.Raster)
 
     def test_direct_band_instantiation(self):
-        self.assertRaises(TypeError, epr.Band)
+        pattern = self.MSG_PATTERN % epr.Band.__name__
+        self.assertRaisesRegex(TypeError, pattern, epr.Band)
 
     def test_direct_dataset_instantiation(self):
-        self.assertRaises(TypeError, epr.Dataset)
+        pattern = self.MSG_PATTERN % epr.Dataset.__name__
+        self.assertRaisesRegex(TypeError, pattern, epr.Dataset)
+
+    def test_direct_Product_instantiation(self):
+        self.assertRaises(ValueError, epr.Product, 'filename')
 
 
 if __name__ == '__main__':
